@@ -4,10 +4,10 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
                        zlim = NULL, col.palette = topo.colors(100), coords = rep(NA, 2)) {
 
    if (!requireNamespace("tkrplot", quietly = TRUE)) stop("the tkrplot package is not available.")
-   if (!requireNamespace("akima", quietly = TRUE))   stop("the akima package is not available.")
+   if (!requireNamespace("interp", quietly = TRUE))   stop("the interp package is not available.")
    # if (!requireNamespace("lattice", quietly = TRUE)) stop("the lattice package is not available.")
    # if (!requireNamespace("rgl", quietly = TRUE))     stop("the rgl package is not available.")
-   
+
    x1lab <- deparse(substitute(x1grid))
    x2lab <- deparse(substitute(x2grid))
    ylab  <- deparse(substitute(surface))
@@ -21,7 +21,7 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
    e.vecs  <- eig$vectors
    se.fit  <- sqrt(diag(covariance))
    surface <- c(surface)
-   
+
    if (is.null(zlim))
       zlim <- range(surface - 3 * se.fit, surface + 3 * se.fit, na.rm = TRUE)
    brks <- seq(zlim[1], zlim[2], length = length(col.palette) + 1)
@@ -41,14 +41,14 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
    mask[mask == 0] <- NA
    mask   <- matrix(mask, ncol = ninterp)
    ind.na <- !is.na(surface)
-   
+
    rp.surface.draw <- function(pnl) {
 
       surf <- pnl$surface
       if (pnl$animation) surf <- surf + pnl$e.isurf
-      
+
       if (pnl$Display == "image") {
-         surf <- akima::interp(pnl$xgrid[pnl$ind.na, 1], pnl$xgrid[pnl$ind.na, 2], surf[pnl$ind.na],
+         surf <- interp::interp(pnl$xgrid[pnl$ind.na, 1], pnl$xgrid[pnl$ind.na, 2], surf[pnl$ind.na],
                         pnl$xg1, pnl$xg2)$z * pnl$mask
          par(mar = c(3, 3, 1, 0) + 0.1, mgp = c(2, 0.5, 0), tcl = -0.2)
          image(pnl$xg1, pnl$xg2, surf, zlim = pnl$zlim, col = pnl$col.palette,
@@ -71,24 +71,24 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
                 zlim = pnl$zlim, theta = pnl$theta, phi = pnl$phi, ticktype = "detailed",
                 col = clr, d = 4, xlab = pnl$x1lab, ylab = pnl$x2lab, zlab = pnl$ylab)
       }
-      
+
       # Draw the confidence interval against the colour key
       if (all(!is.na(pnl$coords)) & pnl$Display == "image" & !pnl$animation) {
          # ind    <- !is.na(pnl$surface)
-         # pred1  <- akima::interp(pnl$xgrid[ind, 1], pnl$xgrid[ind, 2], pnl$surface[ind],
+         # pred1  <- interp::interp(pnl$xgrid[ind, 1], pnl$xgrid[ind, 2], pnl$surface[ind],
                           # pnl$coords[1], pnl$coords[2])$z
-         # se1    <- akima::interp(pnl$xgrid[ind, 1], pnl$xgrid[ind, 2], pnl$se.fit[ind],
+         # se1    <- interp::interp(pnl$xgrid[ind, 1], pnl$xgrid[ind, 2], pnl$se.fit[ind],
                           # pnl$coords[1], pnl$coords[2])$z
 
-         se.fit <- akima::interp(pnl$xgrid[pnl$ind.na, 1], pnl$xgrid[pnl$ind.na, 2], pnl$se.fit[pnl$ind.na],
+         se.fit <- interp::interp(pnl$xgrid[pnl$ind.na, 1], pnl$xgrid[pnl$ind.na, 2], pnl$se.fit[pnl$ind.na],
                           pnl$xg1, pnl$xg2)$z * pnl$mask
          ind    <- !is.na(c(surf))
          xg     <- as.matrix(expand.grid(pnl$xg1, pnl$xg2))
-         pred1  <- akima::interp(xg[ind, 1], xg[ind, 2], c(surf)[ind],
+         pred1  <- interp::interp(xg[ind, 1], xg[ind, 2], c(surf)[ind],
                           pnl$coords[1], pnl$coords[2])$z
-         se1    <- akima::interp(xg[ind, 1], xg[ind, 2], c(se.fit)[ind],
+         se1    <- interp::interp(xg[ind, 1], xg[ind, 2], c(se.fit)[ind],
                           pnl$coords[1], pnl$coords[2])$z
-         
+
          # Is pretty ok here?
          # col.range <- range(pretty(range(pred1), 20))
          ci <- c(pred1 - 2 * se1, pred1 + 2 * se1)
@@ -110,7 +110,7 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
 #         sm.surface3d(xgrid, e.sim[ , , 1],
 #                    scaling = scaling, zlim = range(e.sim))
 #      }
-      
+
       if (pnl$animation == "rgl") {
          scaling <- rp.plot3d(x[,1], y, x[,2], ylim = range(y, e.sim))
          # load("scaling.dmp")
@@ -127,23 +127,23 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
                     scaling = scaling, zlim = range(e.sim))
                rgl::par3d(skipRedraw = FALSE)
                # Sys.sleep(0.1)
-            }  
+            }
          }
       }
-      
+
       pnl
    }
-   
+
    rp.surface.redraw <- function(pnl) {
       rp.tkrreplot(pnl, plot)
       pnl
    }
-   
+
    rp.key.redraw <- function(pnl) {
       rp.tkrreplot(pnl, key)
       pnl
    }
-   
+
    animate <- function(pnl) {
       pnl$animation  <- !pnl$animation
       if (pnl$animation) {
@@ -151,15 +151,15 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
                                      rnorm(length(pnl$surface))
          pnl$e.sim.old  <- rep(0, length(pnl$surface))
          pnl$isurf      <- 1
-   	     rp.control.put(pnl$panelname, pnl)      
+   	     rp.control.put(pnl$panelname, pnl)
    	     rp.timer(pnl, 1, animation.call, function(pnl) pnl$animation)
          pnl$e.isurf    <- rep(0, length(pnl$surface))
-  	     rp.control.put(pnl$panelname, pnl)      
+  	     rp.control.put(pnl$panelname, pnl)
          rp.tkrreplot(pnl, plot)
       }
       pnl
    }
-   
+
    animation.call <- function(pnl) {
    	  Sys.sleep(0.01 + pnl$Speed / 100)
    	  if (pnl$isurf == ntime + 1) {
@@ -182,7 +182,7 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
         # pnl$npdf <- pnl$npdf + 1
       pnl
    }
-   
+
    mouse <- function(pnl, x, y) {
    	  pnl$coords <- c(x, y)
    	  rp.control.put(pnl$panelname, pnl)
@@ -256,6 +256,6 @@ rp.surface <- function(surface, covariance, x1grid, x2grid, x, y, Display = "per
       col.fn(pnl)
       layout(1)
    }
-   
+
    invisible()
 }
